@@ -12,11 +12,21 @@
 
 import datetime
 import errno
+import json
 import os
 import shutil
 import tarfile
 
-import docker.errors
+try:
+    import docker.errors
+except (ImportError, ModuleNotFoundError):
+    pass
+
+try:
+    import podman.errors.exceptions
+except (ImportError, ModuleNotFoundError):
+    pass
+
 import git
 import requests
 from requests import exceptions as requests_exc
@@ -109,8 +119,8 @@ class PushTask(EngineTask):
     def push_image(self, image):
         kwargs = dict(stream=True, decode=True)
 
-        for response in self.engine_client.push(
-                image.canonical_name, **kwargs):
+        for response in self.engine_client.images.push(image.canonical_name,
+                                                       **kwargs):
             if 'stream' in response:
                 self.logger.info(response['stream'])
             elif 'errorDetail' in response:
@@ -367,17 +377,33 @@ class BuildTask(EngineTask):
         pull = self.conf.pull if image.parent is None else False
 
         buildargs = self.update_buildargs()
+
+        kwargs = {}
+        if self.conf.engine == engine.Engine.PODMAN.value:
+            # TODO(kevko): dockerfile path is a workaround,
+            # should be removed as soon as it will be fixed in podman-py
+            # https://github.com/containers/podman-py/issues/177
+            kwargs["dockerfile"] = image.path + '/Dockerfile'
+            # Podman squash is different by default
+            # https://github.com/containers/buildah/issues/1234
+            if self.conf.squash:
+                kwargs["squash"] = False
+                kwargs["layers"] = False
+            else:
+                kwargs["layers"] = True
         try:
-            for stream in \
-                self.engine_client.build(path=image.path,
-                                         tag=image.canonical_name,
-                                         nocache=not self.conf.cache,
-                                         rm=True,
-                                         decode=True,
-                                         network_mode=self.conf.network_mode,
-                                         pull=pull,
-                                         forcerm=self.forcerm,
-                                         buildargs=buildargs):
+            for stream in self.engine_client.images.build(
+                    path=image.path,
+                    tag=image.canonical_name,
+                    nocache=not self.conf.cache,
+                    rm=True,
+                    network_mode=self.conf.network_mode,
+                    pull=pull,
+                    forcerm=self.forcerm,
+                    buildargs=buildargs,
+                    **kwargs)[1]:
+                if self.conf.engine == engine.Engine.PODMAN.value:
+                    stream = json.loads(stream)
                 if 'stream' in stream:
                     for line in stream['stream'].split('\n'):
                         if line:
@@ -396,10 +422,18 @@ class BuildTask(EngineTask):
 
         except engine.getEngineException(self.conf) as e:
             image.status = Status.ERROR
-            if isinstance(e, docker.errors.BuildError):
-                for line in e.build_log:
-                    if 'stream' in line:
-                        self.logger.error(line['stream'].strip())
+            if self.conf.engine == engine.Engine.DOCKER.value:
+                if isinstance(e, docker.errors.BuildError):
+                    for line in e.build_log:
+                        if 'stream' in line:
+                            self.logger.error(line['stream'].strip())
+            elif self.conf.engine == engine.Engine.PODMAN.value:
+                if isinstance(e, podman.errors.exceptions.BuildError):
+                    for line in e.build_log:
+                        line = json.loads(line)
+                        if 'stream' in line:
+                            self.logger.error(line['stream'].strip())
+
             self.logger.exception('Unknown container engine '
                                   'error when building')
 
@@ -414,12 +448,23 @@ class BuildTask(EngineTask):
 
     def squash(self):
         image_tag = self.image.canonical_name
-        image_id = self.engine_client.inspect_image(image_tag)['Id']
+        image_id = self.engine_client.images.get(image_tag).id
 
-        parent_history = self.engine_client.history(self.image.parent_name)
-        parent_last_layer = parent_history[0]['Id']
-        self.logger.info('Parent lastest layer is: %s' % parent_last_layer)
+        parent = self.engine_client.images.get(self.image.parent_name)
+        parent_history = parent.history()
+        parent_last_layer = ""
+        for layer in parent_history:
+            if layer["Tags"] is not None and \
+               self.image.parent_name in layer["Tags"]:
+                parent_last_layer = layer["Id"]
+                break
+        if not parent_last_layer:
+            self.logger.error('Parent last layer is not found, '
+                              'cannot squash.')
+            self.image.status = Status.ERROR
+            return
 
+        self.logger.info('Parent last layer is: %s' % parent_last_layer)
         utils.squash(image_id, image_tag, from_layer=parent_last_layer,
                      cleanup=self.conf.squash_cleanup,
                      tmp_dir=self.conf.squash_tmp_dir)
